{{   S2  Expansion Board - PWIT  Demo #1  Wireless (XBee) S2 Motion Methods

      
     Nicholas G. Lordi  V.1   December 2011

     This demo is designed to exercise the S2 motion methods, using point-to-point
     communication between 2 XBee nodes, where one node represents the Propeller
     Wireless Intelligent Terminal (PWIT).  The demo is installed on the S2. In my
     case, the XBee was attached to an expansion board inserted on top of the S2 and
     connected to hacker port pins P0 (XBee dout) & P1 (XBee din).  This pogram is
     installed on the S2 propeller. The companion program, PWIT_1, must be installed
     on the PWIT propeller.  See PWIT_1.spin for a description of the program operations.                         
     See S2.spin for descriptions of the motion controlling methods.                                     

}}


CON

   _clkmode = xtal1 +pll16x
   _xinfreq = 5_000_000
  
    
   XB_RX    =  0
   XB_Tx    =  1
   XB_Baud  =  9600

VAR
'' User alterable parameters.
   byte  demo_select  
   long  Spd, Dist, Deg, Rad, Lvel, Rvel, Tim
   

OBJ

   s2  : "s2"               ' S2 Drivers
   xb  : "Xbee_Object"      ' XBee Drivers

PUB  Start   

     
     s2.start
     s2.start_motors  
     
     xb.start(XB_Rx, XB_Tx, 0, XB_Baud)
     xb.Delay(500)

'' Parameter default values.     
     Spd := 5
     Dist := 200
     Deg := 10
     Rad := 200
     Lvel := 100
     Rvel := 100
     Tim := 500
     demo_select := 60
     
     
'' Main loop - select desired S2 operation.     
  repeat        
     demo_select := xb.rx                 
     If demo_select == 65  
         s2.delay_tenths(3)
         repeat until demo_select == 42   

           demo_select := xb.rx
           CASE  demo_select
             48  :  s2.go_forward(Dist)                         
             49  :  s2.go_back(Dist)                                           
             50  :  s2.go_left(Dist)                                           
             51  :  s2.go_right(Dist)                                         
             52  :  Dist := Dist + 50
                    sendData(Dist)                                        
             53  :  Dist := Dist - 50 #> 0                     
                    sendData(Dist)                    
             54  :  Spd := Spd + 1 <# 15                     
                    sendData(Spd)
             55  :  Spd := Spd - 1 #> 1                     
                    sendData(Spd)
                         
                          
     ElseIf demo_select == 66              
         s2.delay_tenths(3)
         repeat until demo_select == 42
         
           demo_select := xb.rx  
           CASE  demo_select 
             48  :  s2.turn_deg(Deg)                                  
             49  :  s2.turn_deg(-Deg)             
             50  :  s2.arc_deg(Deg,Rad)
             51  :  s2.arc_deg(-Deg,Rad)
             52  :  Deg := Deg + 5 <# 360                                         
                    sendData(Deg)
             53  :  Deg := Deg - 5 #> 0                     
                    sendData(Deg)            
             54  :  Rad := Rad + 50
                    sendData(Rad)
             55  :  Rad := Rad - 50 #> 0                    
                    sendData(Rad)
           

     ElseIf demo_select == 67
         s2.delay_tenths(3) 
         repeat until demo_select == 42
         
           demo_select := xb.rx
           CASE  demo_select 
             48  :  s2.wheels_now(Lvel, Rvel, Tim)
             49  :  Lvel := Lvel + 10 <# 255 
                    sendData(Lvel)                     
             50  :  Lvel := Lvel - 10 #> -255
                    sendData(Lvel)                      
             51  :  Rvel := Rvel + 10 <# 255
                    sendData(Rvel)                   
             52  :  Rvel := Rvel - 10 #> -255
                    sendData(Rvel)                   
             53  :  Tim := Tim + 50
                    sendData(Tim)
             54  :  Tim := Tim - 50 #> 0
                    sendData(Tim)
                    
            
PRI  sendData(aData)   

     xb.dec(aData)
     xb.CR
     

                  
 

                
           


                                     